@@ -2,10 +2,9 @@ package DBIx::Class::Schema::Loader::DBI::Component::QuotedDefault;
 
 use strict;
 use warnings;
-use base 'DBIx::Class::Schema::Loader::DBI';
-use mro 'c3';
+use Class::C3;
 
-our $VERSION = '0.07048_01';
+our $VERSION = '0.05001';
 
 =head1 NAME
 
@@ -35,19 +34,8 @@ sub _columns_info_for {
             if ($def =~ /^["'](.*?)['"](?:::[\w\s]+)?\z/) {
                 $info->{default_value} = $1;
             }
-# Some DBs (eg. Pg) put parenthesis around negative number defaults
-            elsif ($def =~ /^\((-?\d.*?)\)(?:::[\w\s]+)?\z/) {
-                $info->{default_value} = $1;
-            }
-            elsif ($def =~ /^(-?\d.*?)(?:::[\w\s]+)?\z/) {
-                $info->{default_value} = $1;
-            }
-            elsif ($def =~ /^NULL:?/i) {
-                my $null = 'null';
-                $info->{default_value} = \$null;
-            }
             else {
-                $info->{default_value} = \$def;
+                $info->{default_value} = $def =~ /^\d/ ? $def : \$def;
             }
         }
     }
@@ -62,9 +50,9 @@ sub _columns_info_for {
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-See L<DBIx::Class::Schema::Loader/AUTHORS>.
+See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
 
 =head1 LICENSE
 
